@@ -245,7 +245,8 @@ def run_profiler(problem, steps):
     #    4 ms convolution
     #    1 ms setting parameters and computing nllf
     from .util import profile
-    p = initpop.random_init(int(steps), None, problem)
+    p = initpop.random_init(
+        int(steps), initial=None, bounds=None, use_point=False,problem=problem)
     # Note: map is an iterator in python 3
     profile(lambda *args: list(map(*args)), problem.nllf, p)
 
@@ -386,6 +387,7 @@ def config_matplotlib(backend=None):
     for modules which are completely dedicated to plotting, but these modules
     should never be imported at the module level.
     """
+    import matplotlib as mpl
 
     # When running from a frozen environment created by py2exe, we will not
     # have a range of backends available, and must set the default to WXAgg.
@@ -397,20 +399,29 @@ def config_matplotlib(backend=None):
         if backend is None:
             backend = 'WXAgg'
 
-    import matplotlib
+    ## CRUFT: check that backend is valid, trying alternates if an import fails
+    #if backend is None:
+    #    backend = os.environ.get('MPLBACKEND', mpl.rcParams['backend'])
+    #import importlib
+    #for name in (backend, 'MacOSX', 'Qt5Agg', 'Qt4Agg', 'Gtk3Agg', 'TkAgg', 'WXAgg'):
+    #    path = 'matplotlib.backends.backend_' + name.lower()
+    #    try:
+    #        importlib.import_module(path)
+    #        backend = name
+    #        break
+    #    except ImportError:
+    #        backend = None
 
     # Specify the backend to use for plotting and import backend dependent
-    # classes. Note that this must be done before importing pyplot to have an
+    # classes.  This must be done before importing pyplot to have an
     # effect.  If no backend is given, let pyplot use the default.
     if backend is not None:
-        matplotlib.use(backend)
+        mpl.use(backend)
 
     # Disable interactive mode so that plots are only updated on show() or
-    # draw(). Note that the interactive function must be called before
-    # selecting a backend or importing pyplot, otherwise it will have no
-    # effect.
-
-    matplotlib.interactive(False)
+    # draw(). The interactive function must be called before importing pyplot,
+    # otherwise it will have no effect.
+    mpl.interactive(False)
 
     #configure the plot style
     line_width = 1
@@ -441,7 +452,7 @@ def config_matplotlib(backend=None):
         'svg.fonttype': 'none',
         'savefig.dpi': 100,
     }
-    matplotlib.rcParams.update(plot_style)
+    mpl.rcParams.update(plot_style)
 
 def beep():
     """
@@ -527,7 +538,7 @@ def main():
     # If no GUI specified and not editing, then use the default mpl
     # backend for the python version.
     if opts.batch or opts.remote or opts.noshow:  # no interactivity
-        config_matplotlib(backend='Agg')
+        config_matplotlib(backend='agg')
     else:  # let preview use default graphs
         config_matplotlib()
 
